==> kafka-clients-0.9.0.1-sources.jar: org/apache/kafka/common/requests/ResponseSend.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.kafka.common.requests;

import org.apache.kafka.common.network.NetworkSend;
import org.apache.kafka.common.protocol.types.Struct;

import java.nio.ByteBuffer;

public class ResponseSend extends NetworkSend {

    public ResponseSend(String destination, ResponseHeader header, Struct body) {
        super(destination, serialize(header, body));
    }

    public ResponseSend(String destination, ResponseHeader header, AbstractRequestResponse response) {
        this(destination, header, response.toStruct());
    }

    private static ByteBuffer serialize(ResponseHeader header, Struct body) {
        ByteBuffer buffer = ByteBuffer.allocate(header.sizeOf() + body.sizeOf());
        header.writeTo(buffer);
        body.writeTo(buffer);
        buffer.rewind();
        return buffer;
    }
}

==> kafka-clients-0.10.0.1-sources.jar: org/apache/kafka/common/requests/ResponseSend.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.kafka.common.requests;

import org.apache.kafka.common.network.NetworkSend;
import org.apache.kafka.common.protocol.types.Struct;

import java.nio.ByteBuffer;

public class ResponseSend extends NetworkSend {

    public ResponseSend(String destination, ResponseHeader header, Struct body) {
        super(destination, serialize(header, body));
    }

    public ResponseSend(String destination, ResponseHeader header, AbstractRequestResponse response) {
        this(destination, header, response.toStruct());
    }

    public static ByteBuffer serialize(ResponseHeader header, Struct body) {
        ByteBuffer buffer = ByteBuffer.allocate(header.sizeOf() + body.sizeOf());
        header.writeTo(buffer);
        body.writeTo(buffer);
        buffer.rewind();
        return buffer;
    }
}
